
NIP-52
======

Issued Claims
-------------

`draft` `optional` `author:neilck`

This NIP is currently in draft, and review / comments are sought. May overlap with [NIP-32](https://github.com/nostr-protocol/nips/blob/39bfb2db32899dd2eb4a7c9a313f27103a18409b/32.md).

A claim is a statement of fact made by an issuer regarding a subject.
Example claims include
- Alice graduated from the Univeristy of Southern California
- Bob, the control of pubkey 123EED..., also controls Twitter handle tinydancer
- Charlie is over 21 years of age

Like Kind 0 metadata, issued claims provide additional data about pubkey, and by extension, the controller of the pukey.
Unlike Kind 0 metadata, the data is sent by and vouched for by issuers, which is more trusthworthy than self-reported data, provided we trust the issuer. 

The concept of an issuer comes from [Verifiable Credentials](https://www.w3.org/TR/vc-data-model/).

This NIP defines two new event kinds. 

It reserves two event kinds (30001, 1001).

- `30001 - issue claim`
- `1001 - refresh claim request`

An issue claim event records what one user attests is true about another user. 

## Kind 30001: Issue Claim

Sent by a user acting as an issuer, submitting a claim about another user, the claim's subject.

```json
{
  "id": <32-bytes lowercase hex-encoded sha256 of the the serialized event data>
  "pubkey": <32-bytes lowercase hex-encoded public key of the issuer>,
  "created_at": <unix timestamp in seconds>,
  "kind": 30001,
  "tags": [
    ["p", <32-bytes hex of the subject's pubkey>, <recommended relay URL>],
    ["d", <32-bytes hex of the subject's pubkey + claim type>],
    ["claim_type", <optional string specifying claim type>],
    ["is_maintained", <optional boolean, yes if refresh claim supported>]
  ],
  "content": <claim data>,
  "sig": <64-bytes signature of the sha256 hash of the serialized event data, which is the same as the "id" field>
}
```

For example. issuer nostr.directory with hexPubKey 2a1...234 is claiming that nostr user with hexPubKey 3bf...6w6 also controls twitter handle fiatjaf  
```json
{
  "id": <32-bytes lowercase hex-encoded sha256 of the the serialized event data>
  "pubkey": "2a1...234",
  "created_at": <unix timestamp in seconds>,
  "kind": 30001,
  "tags": [
    ["p", "3bf...6w6", <recommended relay URL>],
    ["d", "3bf...6w6:twitteraccount"],
    ["claim_type", "twitteraccount"],
    ["is_maintained", true]
  ],
  "content": {
    "twitter_handle": "fiatjaf",
    "profile_url": "https://twitter.com/fiatjaf"
  },
  "sig": <64-bytes signature of the sha256 hash of the serialized event data, which is the same as the "id" field>
}
```

`"d" tag` is required as the event is treated as a parameterized replaceable event [NIP-33](https://github.com/nostr-protocol/nips/blob/master/33.md). Issuers issuing more than one type of claim will need to append a claim type identifier to the subject's pubkey hex to prevent overwrites.

The p tag MUST contain exactly one entry, the pubkey of the claim's subject.

Self-issued claims (issuer is the subject) is specifically allowed.


## Kind 1001: Refresh Claim Request

A claim may change over time. This event allows a user to request the issuer submit an updated issue claim event for the same subject and claim_type.

Refresh Claim Request
```json
{
  "id": <32-bytes lowercase hex-encoded sha256 of the the serialized event data>
  "pubkey": <32-bytes lowercase hex-encoded public key of the sender>,
  "created_at": 1674607473,
  "kind": 1001,
  "tags": [
        ["e", <kind>:<pubkey>:<d-tag>, <relay-url>]
  ],
  "sig": <64-bytes signature of the sha256 hash of the serialized event data, which is the same as the "id" field>
}
```

For example, if issued claim states a user is employed by Microsoft, but is 1 year out of date (1643099996 = Jan 25, 2022), an client may request issue update the issued claim to check if they still work there.

Issued Claim Example
```json
{
  "created_at": 1643099996,
  "kind": 30001,
  "tags": [
    ["p", "37a...100", <recommended relay URL>],
    ["d", "37a...100:employer"],
    ["claim_type", "employer"],
    ["is_maintained", true]
  ],
  "content": {
    "organization_name": "microsoft",
    "title": "Senior Software Developer"
  },
  "sig": <64-bytes signature of the sha256 hash of the serialized event data, which is the same as the "id" field>
}
```

Related Refresh Claim Request Example
```json
{
  "id": <32-bytes lowercase hex-encoded sha256 of the the serialized event data>
  "pubkey": <32-bytes lowercase hex-encoded public key of the sender>,
  "created_at": 1674607473,
  "kind": 1001,
  "tags": [
        ["e", "30001:37a...100:employer", <relay-url>]
  ],
  "sig": <64-bytes signature of the sha256 hash of the serialized event data, which is the same as the "id" field>
}
```

A client SHOULD check that the original event contains "is_maintained": true before sending event to relay
A relay MAY choose to ignore this event if original event does not contain "is_maintained"

Design Notes
------------

### Why treat issue claim events as a parameterized replaceable event (NIP-33)?

Treating issue claim events as parameterized replaceable events allows any consumer to get the only latest issue claim event for a user by setting a subscription filter specifying the kind, issuer, the subject as the p tag, and a limit of 1.

### Why is "is_maintained" necessary?

It's optional, and not technically necessary, but is a practical consideration. 

- If adhered to, prevents clients from sending refresh claim request events that are useless, reducing "garbage" events relays have to handle
- Allows users acting as issuers to periodically send new issue claim events, updating claims for individual users "on demand" only when necessary


Motivation
----------
As a protocol, Nostr is application agnostic, easy to implement, and censorship resistant. While current apps built on Nostr focus on messaging (Twitter, Telegram, etc.) Nostr can be the underlying protocol of other social media apps as well (Instagram, LinkedIn, Tinder, etc.). These apps require more profile information than Nostr current supports. Rather than each app implementing its own profile, it would be nice if we can leverage Nostr for decentralized identity.
